@@ -2,7 +2,6 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.services.transfer import iterable_response_to_dict
 from globus_cli.termio import formatted_print
 from globus_cli.utils import PagingWrapper
 
@@ -165,6 +164,7 @@ def task_list(
     This lists your most recent tasks. The tasks displayed may be filtered by a number
     of attributes, each with a separate commandline option.
     """
+    from globus_cli.services.transfer import iterable_response_to_dict
 
     def _process_filterval(prefix, value, default=None):
         if value:
@@ -205,7 +205,10 @@ def task_list(
     transfer_client = login_manager.get_transfer_client()
     task_iterator = PagingWrapper(
         transfer_client.paginated.task_list(
-            query_params={"filter": filter_string[:-1]},  # remove trailing /
+            query_params={
+                "filter": filter_string[:-1],  # remove trailing /
+                "orderby": "request_time DESC",
+            },
         ).items(),
         limit=limit,
     )
