@@ -1,18 +1,23 @@
 from __future__ import annotations
 
 import click
-from globus_sdk import TransferData
+import globus_sdk
 
-from globus_cli import utils
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import (
     ENDPOINT_PLUS_OPTPATH,
-    TaskPath,
     command,
+    encrypt_data_option,
+    fail_on_quota_errors_option,
     mutex_option_group,
+    preserve_timestamp_option,
+    skip_source_errors_option,
+    sync_level_option,
     task_submission_options,
+    transfer_batch_option,
+    transfer_recursive_option,
+    verify_checksum_option,
 )
-from globus_cli.services.transfer import autoactivate
 from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
 
 
@@ -107,42 +112,21 @@ fi
 ----
 """,
 )
+@click.argument(
+    "source", metavar="SOURCE_ENDPOINT_ID[:SOURCE_PATH]", type=ENDPOINT_PLUS_OPTPATH
+)
+@click.argument(
+    "destination", metavar="DEST_ENDPOINT_ID[:DEST_PATH]", type=ENDPOINT_PLUS_OPTPATH
+)
 @task_submission_options
-@click.option(
-    "--recursive",
-    "-r",
-    is_flag=True,
-    help="SOURCE_PATH and DEST_PATH are both directories, do a recursive dir transfer",
-)
-@click.option(
-    "--sync-level",
-    "-s",
-    default=None,
-    show_default=True,
-    type=click.Choice(("exists", "size", "mtime", "checksum"), case_sensitive=False),
-    help=(
-        "How will the Transfer task determine whether or not to "
-        "actually transfer a file over the network?"
-    ),
-)
-@click.option(
-    "--preserve-mtime",
-    is_flag=True,
-    default=False,
-    help="Preserve file and directory modification times.",
-)
-@click.option(
-    "--verify-checksum/--no-verify-checksum",
-    default=True,
-    show_default=True,
-    help="Verify checksum after transfer.",
-)
-@click.option(
-    "--encrypt",
-    is_flag=True,
-    default=False,
-    help="Encrypt data sent through the network.",
-)
+@sync_level_option(aliases=("-s",))
+@transfer_batch_option
+@transfer_recursive_option
+@preserve_timestamp_option(aliases=("--preserve-mtime",))
+@verify_checksum_option
+@encrypt_data_option(aliases=("--encrypt",))
+@skip_source_errors_option
+@fail_on_quota_errors_option
 @click.option(
     "--delete",
     is_flag=True,
@@ -152,17 +136,6 @@ fi
         "Only applies to recursive directory transfers."
     ),
 )
-@click.option(
-    "--batch",
-    type=click.File("r"),
-    help=(
-        "Accept a batch of source/dest path pairs from a file. Use the special `-` "
-        "value to read from stdin; otherwise opens the file from the argument and "
-        "passes through lines from that file. Uses SOURCE_ENDPOINT_ID and "
-        "DEST_ENDPOINT_ID as passed on the commandline. Commandline paths are still "
-        "allowed and are used as prefixes to the batchmode inputs."
-    ),
-)
 @click.option(
     "--external-checksum",
     help=(
@@ -177,26 +150,6 @@ fi
     show_default=True,
     help=("Specify an algorithm for --external-checksum or --verify-checksum"),
 )
-@click.option(
-    "--skip-source-errors",
-    is_flag=True,
-    default=False,
-    show_default=True,
-    help=(
-        "Skip over source paths that hit permission denied or file not "
-        "found errors during the transfer."
-    ),
-)
-@click.option(
-    "--fail-on-quota-errors",
-    is_flag=True,
-    default=False,
-    show_default=True,
-    help=(
-        "Cause the task to fail if any quota exceeded errors are hit "
-        "during the transfer."
-    ),
-)
 @click.option(
     "--exclude",
     multiple=True,
@@ -209,12 +162,6 @@ fi
         "multiple patterns."
     ),
 )
-@click.argument(
-    "source", metavar="SOURCE_ENDPOINT_ID[:SOURCE_PATH]", type=ENDPOINT_PLUS_OPTPATH
-)
-@click.argument(
-    "destination", metavar="DEST_ENDPOINT_ID[:DEST_PATH]", type=ENDPOINT_PLUS_OPTPATH
-)
 @click.option("--perf-cc", type=int, hidden=True)
 @click.option("--perf-p", type=int, hidden=True)
 @click.option("--perf-pp", type=int, hidden=True)
@@ -235,9 +182,9 @@ def transfer_command(
     fail_on_quota_errors,
     exclude,
     label,
-    preserve_mtime,
+    preserve_timestamp,
     verify_checksum,
-    encrypt,
+    encrypt_data,
     submission_id,
     dry_run,
     delete,
@@ -315,9 +262,12 @@ def transfer_command(
 
     {AUTOMATIC_ACTIVATION}
     """
+    from globus_cli.services.transfer import add_batch_to_transfer_data, autoactivate
+
     source_endpoint, cmd_source_path = source
     dest_endpoint, cmd_dest_path = destination
 
+    # avoid 'mutex_option_group', emit a custom error message
     if recursive and batch:
         raise click.UsageError(
             "You cannot use --recursive in addition to --batch. "
@@ -357,15 +307,15 @@ def transfer_command(
         filter_rules = None
 
     transfer_client = login_manager.get_transfer_client()
-    transfer_data = TransferData(
+    transfer_data = globus_sdk.TransferData(
         transfer_client,
         source_endpoint,
         dest_endpoint,
         label=label,
         sync_level=sync_level,
         verify_checksum=verify_checksum,
-        preserve_timestamp=preserve_mtime,
-        encrypt_data=encrypt,
+        preserve_timestamp=preserve_timestamp,
+        encrypt_data=encrypt_data,
         submission_id=submission_id,
         deadline=deadline,
         skip_source_errors=skip_source_errors,
@@ -380,28 +330,9 @@ def transfer_command(
     )
 
     if batch:
-
-        @click.command()
-        @click.option("--external-checksum")
-        @click.option("--recursive", "-r", is_flag=True)
-        @click.argument("source_path", type=TaskPath(base_dir=cmd_source_path))
-        @click.argument("dest_path", type=TaskPath(base_dir=cmd_dest_path))
-        @mutex_option_group("--recursive", "--external-checksum")
-        def process_batch_line(dest_path, source_path, recursive, external_checksum):
-            """
-            Parse a line of batch input and turn it into a transfer submission
-            item.
-            """
-            transfer_data.add_item(
-                str(source_path),
-                str(dest_path),
-                external_checksum=external_checksum,
-                checksum_algorithm=checksum_algorithm,
-                recursive=recursive,
-            )
-
-        utils.shlex_process_stream(process_batch_line, batch)
-
+        add_batch_to_transfer_data(
+            cmd_source_path, cmd_dest_path, checksum_algorithm, transfer_data, batch
+        )
     else:
         transfer_data.add_item(
             cmd_source_path,
