@@ -1,16 +1,6 @@
-from globus_cli.parsing.commands import command, group, main_group
-from globus_cli.parsing.mutex_group import MutexInfo, mutex_option_group
-from globus_cli.parsing.one_use_option import one_use_option
-from globus_cli.parsing.shared_options import (
-    collection_id_arg,
-    delete_and_rm_options,
-    endpoint_id_arg,
-    no_local_server_option,
-    security_principal_opts,
-    synchronous_task_wait_options,
-    task_submission_options,
-)
-
+from .commands import command, group, main_group
+from .mutex_group import MutexInfo, mutex_option_group
+from .one_use_option import one_use_option
 from .param_types import (
     ENDPOINT_PLUS_OPTPATH,
     ENDPOINT_PLUS_REQPATH,
@@ -21,9 +11,30 @@ from .param_types import (
     ParsedIdentity,
     StringOrNull,
     TaskPath,
+    TimedeltaType,
     UrlOrNull,
     nullable_multi_callback,
 )
+from .shared_options import (
+    collection_id_arg,
+    delete_and_rm_options,
+    endpoint_id_arg,
+    no_local_server_option,
+    security_principal_opts,
+    synchronous_task_wait_options,
+    task_notify_option,
+    task_submission_options,
+)
+from .shared_options.transfer_task_options import (
+    encrypt_data_option,
+    fail_on_quota_errors_option,
+    preserve_timestamp_option,
+    skip_source_errors_option,
+    sync_level_option,
+    transfer_batch_option,
+    transfer_recursive_option,
+    verify_checksum_option,
+)
 
 __all__ = [
     # replacement decorators
@@ -42,6 +53,7 @@ __all__ = [
     "ParsedIdentity",
     "StringOrNull",
     "TaskPath",
+    "TimedeltaType",
     "UrlOrNull",
     "mutex_option_group",
     "nullable_multi_callback",
@@ -54,4 +66,13 @@ __all__ = [
     "synchronous_task_wait_options",
     "security_principal_opts",
     "no_local_server_option",
+    "transfer_recursive_option",
+    "transfer_batch_option",
+    "sync_level_option",
+    "task_notify_option",
+    "fail_on_quota_errors_option",
+    "encrypt_data_option",
+    "preserve_timestamp_option",
+    "skip_source_errors_option",
+    "verify_checksum_option",
 ]
