@@ -4,7 +4,12 @@ from .activation import (
     supported_activation_methods,
 )
 from .client import CustomTransferClient
-from .data import assemble_generic_doc, display_name_or_cname, iterable_response_to_dict
+from .data import (
+    add_batch_to_transfer_data,
+    assemble_generic_doc,
+    display_name_or_cname,
+    iterable_response_to_dict,
+)
 from .delegate_proxy import fill_delegate_proxy_activation_requirements
 from .recursive_ls import RecursiveLsResponse
 
@@ -26,4 +31,5 @@ __all__ = (
     "display_name_or_cname",
     "iterable_response_to_dict",
     "assemble_generic_doc",
+    "add_batch_to_transfer_data",
 )
